
# References

- https://pydantic-docs.helpmanual.io/
- https://python-patterns.guide/
- https://docs.pytest.org/en/7.1.x/getting-started.html#get-started
- https://github.com/samuelcolvin/pydantic
- https://python-poetry.org/docs/pyproject
- https://github.com/wemake-services/wemake-python-package

## Style

- https://code.visualstudio.com/docs/languages/python
- https://code.visualstudio.com/docs/python/linting
- https://code.visualstudio.com/api/language-extensions/snippet-guide
- https://semver.org/
- https://snyk.io/blog/python-poetry-package-manager/

### Taxonomy

- https://github.com/MISP/misp-taxonomies/blob/main/tools/machinetag.py
- https://www.misp-project.org/taxonomies.html#_mapping_of_taxonomies
- https://github.com/MISP/misp-taxonomies
- https://github.com/MISP/misp-taxonomies/blob/main/tools/docs/images/taxonomy-explanation.png

## Entorno

- vs-code
    - Extensiones:
        - snyk
        - flake8

## The Zen of Python

```python
import this
> The Zen of Python, by Tim Peters
> 
> Beautiful is better than ugly.
> Explicit is better than implicit.
> Simple is better than complex.
> Complex is better than complicated.
> Flat is better than nested.
> Sparse is better than dense.
> Readability counts.
> Special cases aren't special enough to break the rules.
> Although practicality beats purity.
> Errors should never pass silently.
> Unless explicitly silenced.
> In the face of ambiguity, refuse the temptation to guess.
> There should be one-- and preferably only one --obvious way to do it.
> Although that way may not be obvious at first unless you're Dutch.
> Now is better than never.
> Although never is often better than *right* now.
> If the implementation is hard to explain, it's a bad idea.
> If the implementation is easy to explain, it may be a good idea.
> Namespaces are one honking great idea -- let's do more of those!
```

# Ackowledgement

We really appreciate the documentation of https://github.com/VirusTotal/vt-py
